@@ -1,6 +1,14 @@
 # -*- coding: utf-8 -*-
 """Module for storage and data manipulation of Froxy class."""
 
+from .__about__ import __version__
+from .__about__ import __author__
+from .__about__ import __email__
+from .__about__ import __github__
+
+__version__ = __version__
+__author__ = f'{__author__} <{__email__}> and <{__github__}>'
+
 # --- Standard libraries ----
 from copy import deepcopy
 
